#### 关于本项目
> 项目的前提基于心里咨询的一些方法论，作者并不是从事相关行业，对于一些见解上的错误，欢迎指正
> 
> glm4、gpt4可以完成整个项目的个体心理状态提取思维链
> 
> 关于数据如何生成的请参考[README.md](../../%E6%A2%A6%E4%B8%8E%E5%88%9B%E9%80%A0%E6%80%A7%E5%88%86%E6%9E%90/README.md)
>


#### 编写目的
[README.md](../../%E6%A2%A6%E4%B8%8E%E5%88%9B%E9%80%A0%E6%80%A7%E5%88%86%E6%9E%90/README.md)


#### 一些已经生成的角色标签卡
[抖音数据分析整理角色标签卡](../docs/README.md)

 

